@@ -1,7 +1,8 @@
 {-# LANGUAGE OverloadedStrings, RankNTypes, ScopedTypeVariables, StandaloneDeriving #-}
 {-# OPTIONS_GHC -Wall -fno-warn-orphans #-}
-module Debian.Debianize.Tests
+module Main
     ( tests
+    , main
     ) where
 
 import Data.Algorithm.Diff.Context (contextDiff)
@@ -20,7 +21,7 @@ import Debian.Changes (ChangeLog(..), ChangeLogEntry(..), parseEntry)
 import Debian.Debianize.Debianize (debianization)
 import Debian.Debianize.Atoms as Atoms
     (Atoms, rulesHead, compat, sourceFormat, changelog, control, missingDependencies, revision,
-     binaryArchitectures, copyright, debVersion, execMap, buildDeps, utilsPackageName, description,
+     binaryArchitectures, copyright, debVersion, execMap, buildDeps, utilsPackageNames, description,
      depends, installData, epochMap {-, sourcePackageName, install, buildDepsIndep-})
 import Debian.Debianize.ControlFile as Deb (SourceDebDescription(..), BinaryDebDescription(..), PackageRelations(..), VersionControlSpec(..))
 import Debian.Debianize.Dependencies (getRulesHead)
@@ -341,7 +342,7 @@ test5 =
                            modL binaryArchitectures (Map.insert (BinPkgName "creativeprompts-data") All) .
                            modL binaryArchitectures (Map.insert (BinPkgName "creativeprompts-development") All) .
                            modL binaryArchitectures (Map.insert (BinPkgName "creativeprompts-production") All) .
-                           setL utilsPackageName (Just (BinPkgName "creativeprompts-data")) .
+                           setL utilsPackageNames (Just (singleton (BinPkgName "creativeprompts-data"))) .
                            modL Atoms.description (Map.insertWith (error "test5") (BinPkgName "creativeprompts-data")
                                                     (T.intercalate "\n" [ "creativeprompts.com data files"
                                                                , "  Static data files for creativeprompts.com"])) .
@@ -530,3 +531,7 @@ testEntry =
                                 , "    files that were supposed to be installed into packages."
                                 , ""
                                 , " -- David Fox <dsf@seereason.com>  Thu, 20 Dec 2012 06:49:25 -0800" ]))
+
+main :: IO ()
+main = runTestTT tests >>= putStrLn . show
+
