@@ -114,7 +114,6 @@ deriving instance Data License
 instance Pretty License where
     pretty (GPL _) = text "GPL"
     pretty (LGPL _) = text "LGPL"
-    pretty (Apache _) = text "Apache"
     pretty BSD3 = text "BSD"
     pretty BSD4 = text "BSD-like"
     pretty PublicDomain = text "Public Domain"
@@ -122,6 +121,7 @@ instance Pretty License where
     pretty OtherLicense = text "Non-distributable"
     pretty MIT = text "MIT"
     pretty (UnknownLicense _) = text "Unknown"
+    pretty x = text (show x)
 
 deriving instance Data NameAddr
 deriving instance Typeable NameAddr
